// SPDX-FileCopyrightText: 2023-2024 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef RESIZABLELABEL_H
#define RESIZABLELABEL_H

// Qt includes
#include <QWidget>
#include <QHash>
#include <QColor>

// Local classes
class ExpandingLabel;
class FontDialog;

// Qt classes
class QLabel;
class QToolButton;
class QSpinBox;

class ResizableLabel : public QWidget
{
    Q_OBJECT

public:
    explicit ResizableLabel(FontDialog *fontDialog, QWidget *parent = nullptr);
    Qt::AlignmentFlag alignment() const;
    bool isBold() const;
    int maxHeight() const;
    int stretch() const;
    void setColor(const QColor &color);
    const QColor &color() const;
    void setFontFamily(const QString &family);
    QString fontFamily() const;
    void resizeText();
    void setText(const QString &displayText, const QString &strippedText);
    void setFormattingVisible(bool state);
    void reset();
    void setText(const QString &text);
    void setStretch(int stretch);

Q_SIGNALS:
    void stretchFactorChanged(int factor);

public Q_SLOTS:
    void setBold(bool state);
    void setAlignment(Qt::AlignmentFlag alignment);
    void setMaxHeight(int height);
    void selectFont();
    void selectColor();

private: // Variables
    FontDialog *m_fontDialog;
    QWidget *m_formatting;
    QToolButton *m_bold;
    QHash<QToolButton *, Qt::AlignmentFlag> m_alignment;
    QSpinBox *m_maxHeight;
    QSpinBox *m_stretch;
    ExpandingLabel *m_label;
    QColor m_color;

};

#endif // RESIZABLELABEL_H
