// SPDX-FileCopyrightText: 2019-2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "IconSizeEngine.h"

// Qt includes
#include <QWidget>
#include <QFont>
#include <QFontMetrics>
#include <QDebug>

// C++ includes
#include <cmath>

IconSizeEngine::IconSizeEngine(QObject *parent) : QObject(parent)
{
    // The following calculation should set m_MHeight to 20(px) if the default
    // font size and family is used. We use os-dependant factors to achieve this.

    QWidget widget;
    const auto metrics = QFontMetrics(widget.font());
    m_MHeight = metrics.boundingRect(QStringLiteral("M")).height()
#ifdef Q_OS_LINUX
                    * 1.17647;
#endif
#ifdef Q_OS_WIN
                    * 1.54836;
#endif
#ifdef Q_OS_MACOS
                    * 1.33333;
#endif

    // If the user's desktop defines another font size, the icons should be scaled accordingly.
}

QSize IconSizeEngine::relativeSize(double factor) const
{
    const int size = relativeWidth(factor);
    return QSize(size, size);
}

int IconSizeEngine::relativeWidth(double factor) const
{
    return int(std::round(m_MHeight * factor));
}
